@@ -30,8 +30,11 @@ class Bitbucket(AtlassianRestAPI):
                             fixed system limits. Default by built-in method: 99999
         :return:
         """
-        url = 'rest/api/1.0/projects/{key}/permissions/users?limit={limit}'.format(key=key, limit=limit)
-        return (self.get(url) or {}).get('values')
+        url = 'rest/api/1.0/projects/{key}/permissions/users'.format(key=key)
+        params = {}
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def project_users_with_administrator_permissions(self, key):
         """
@@ -54,8 +57,11 @@ class Bitbucket(AtlassianRestAPI):
                             fixed system limits. Default by built-in method: 99999
         :return:
         """
-        url = 'rest/api/1.0/projects/{key}/permissions/groups?limit={limit}'.format(key=key, limit=limit)
-        return (self.get(url) or {}).get('values')
+        url = 'rest/api/1.0/projects/{key}/permissions/groups'.format(key=key)
+        params = {}
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def project_groups_with_administrator_permissions(self, key):
         """
@@ -80,15 +86,24 @@ class Bitbucket(AtlassianRestAPI):
                         fixed system limits. Default by built-in method: 99999
         :return:
         """
-        url = 'rest/api/1.0/admin/groups/more-members?context={group}&limit={limit}'.format(group=group, limit=limit)
-        return (self.get(url) or {}).get('values')
+        url = 'rest/api/1.0/admin/groups/more-members'
+        params = {}
+        if limit:
+            params['limit'] = limit
+        if group:
+            params['context'] = group
+        return (self.get(url, params=params) or {}).get('values')
 
     def all_project_administrators(self):
+        """
+        Get the list of project administrators
+        :return:
+        """
         for project in self.project_list():
-            log.info('Processing project: {0} - {1}'.format(project['key'], project['name']))
+            log.info('Processing project: {0} - {1}'.format(project.get('key'), project.get('name')))
             yield {
-                'project_key': project['key'],
-                'project_name': project['name'],
+                'project_key': project.get('key'),
+                'project_name': project.get('name'),
                 'project_administrators': [{'email': x['emailAddress'], 'name': x['displayName']}
                                            for x in self.project_users_with_administrator_permissions(project['key'])]}
 
@@ -100,14 +115,18 @@ class Bitbucket(AtlassianRestAPI):
                         fixed system limits. Default by built-in method: 25
         :return:
         """
-        url = 'rest/api/1.0/projects/{projectKey}/repos?limit={limit}'.format(projectKey=project_key, limit=limit)
-        return (self.get(url) or {}).get('values')
+        url = 'rest/api/1.0/projects/{projectKey}/repos'.format(projectKey=project_key)
+        params = {}
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def get_branches(self, project, repository, base=None, filter=None, start=0, limit=99999, details=True,
                      order_by='MODIFICATION'):
         """
         Retrieve the branches matching the supplied filterText param.
         The authenticated user must have REPO_READ permission for the specified repository to call this resource.
+        :param start:
         :param project:
         :param repository:
         :param base: base branch or tag to compare each branch to (for the metadata providers that uses that information)
@@ -118,7 +137,7 @@ class Bitbucket(AtlassianRestAPI):
         :param order_by: OPTIONAL: ordering of refs either ALPHABETICAL (by name) or MODIFICATION (last updated)
         :return:
         """
-        url = "rest/api/1.0/projects/{project}/repos/{repository}/branches".format(project=project,
+        url = 'rest/api/1.0/projects/{project}/repos/{repository}/branches'.format(project=project,
                                                                                    repository=repository)
         params = {}
         if start:
@@ -164,7 +183,7 @@ class Bitbucket(AtlassianRestAPI):
         :param start:
         :return:
         """
-        url = "rest/api/1.0/projects/{project}/repos/{repository}/pull-requests".format(project=project,
+        url = '/api/1.0/projects/{project}/repos/{repository}/pull-requests'.format(project=project,
                                                                                         repository=repository)
         params = {}
         if state:
@@ -278,9 +297,12 @@ class Bitbucket(AtlassianRestAPI):
         url = 'rest/api/1.0/projects/{project}/repos/{repository}/compare/diff/{path}'.format(project=project,
                                                                                               repository=repository,
                                                                                               path=path)
-        url += '?from={hash_oldest}&to={hash_newest}'.format(hash_oldest=hash_oldest,
-                                                             hash_newest=hash_newest)
-        return (self.get(url) or {}).get('diffs')
+        params = {}
+        if hash_oldest:
+            params['from'] = hash_oldest
+        if hash_newest:
+            params['to'] = hash_newest
+        return (self.get(url, params=params) or {}).get('diffs')
 
     def get_commits(self, project, repository, hash_oldest, hash_newest, limit=99999):
         """
@@ -295,10 +317,14 @@ class Bitbucket(AtlassianRestAPI):
         """
         url = 'rest/api/1.0/projects/{project}/repos/{repository}/commits'.format(project=project,
                                                                                   repository=repository)
-        url += '?since={hash_from}&until={hash_to}&limit={limit}'.format(hash_from=hash_oldest,
-                                                                         hash_to=hash_newest,
-                                                                         limit=limit)
-        return (self.get(url) or {}).get('values')
+        params = {}
+        if hash_oldest:
+            params['since'] = hash_oldest
+        if hash_newest:
+            params['until'] = hash_newest
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def get_commit_info(self, project, repository, commit, path=None):
         """
@@ -308,7 +334,7 @@ class Bitbucket(AtlassianRestAPI):
         :param project:
         :param repository:
         :param commit: the commit ID to retrieve
-        :path :OPTIONAL an optional path to filter the commit by.
+        :param path :OPTIONAL an optional path to filter the commit by.
                         If supplied the details returned may not be for the specified commit.
                         Instead, starting from the specified commit, they will be the details for the first commit
                         affecting the specified path.
@@ -342,10 +368,14 @@ class Bitbucket(AtlassianRestAPI):
         """
         url = 'rest/api/1.0/projects/{project}/repos/{repository}/compare/commits'.format(project=project,
                                                                                           repository=repository)
-        url += '?from={ref_from}&to={ref_to}&limit={limit}'.format(ref_from=ref_from,
-                                                                   ref_to=ref_to,
-                                                                   limit=limit)
-        return (self.get(url) or {}).get('values')
+        params = {}
+        if ref_from:
+            params['from'] = ref_from
+        if ref_to:
+            params['to'] = ref_to
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def get_file_list(self, project, repository, query, limit=100000):
         """
@@ -359,13 +389,14 @@ class Bitbucket(AtlassianRestAPI):
         :param limit: OPTIONAL
         :return:
         """
-        url = "rest/api/1.0/projects/{project}/repos/{repository}/files?at={query}&limit={limit}".format(
-            project=project,
-            repository=repository,
-            query=query,
-            limit=limit)
-
-        return (self.get(url) or {}).get('values')
+        url = 'rest/api/1.0/projects/{project}/repos/{repository}/files'.format(project=project,
+                                                                                repository=repository)
+        params = {}
+        if query:
+            params['at'] = query
+        if limit:
+            params['limit'] = limit
+        return (self.get(url, params=params) or {}).get('values')
 
     def get_content_of_file(self, project, repository, filename, at=None, markup=None):
         """
@@ -381,14 +412,14 @@ class Bitbucket(AtlassianRestAPI):
         :return:
         """
         headers = self.form_token_headers
+        url = 'projects/{project}/repos/{repository}/raw/{filename}/'.format(project=project,
+                                                                             repository=repository,
+                                                                             filename=filename)
         params = {}
         if at is not None:
             params['at'] = at
         if markup is not None:
             params['markup'] = markup
-        url = 'projects/{project}/repos/{repository}/raw/{filename}/'.format(project=project,
-                                                                             repository=repository,
-                                                                             filename=filename)
         return self.get(url, params=params, not_json_response=True, headers=headers)
 
     def get_branches_permissions(self, project, repository, limit=25):
@@ -399,12 +430,12 @@ class Bitbucket(AtlassianRestAPI):
         :param limit:
         :return:
         """
-        url = 'rest/branch-permissions/2.0/projects/{project}/repos/{repository}/restrictions' \
-              '?limit={limit}'.format(project=project,
-                                      repository=repository,
-                                      limit=limit)
-
-        return self.get(url)
+        url = 'rest/branch-permissions/2.0/projects/{project}/repos/{repository}/restrictions'.format(project=project,
+                                                                                                      repository=repository)
+        params = {}
+        if limit:
+            params['limit'] = limit
+        return self.get(url, params=params)
 
     def reindex(self):
         """
